boot.morph: Bootstrapping for a Morphometric Model

View source: R/model.R

boot.morphR Documentation

Bootstrapping for a Morphometric Model

Description

Simulates bootstrap resamples and re-fits the original morphometric model to each one. The resulting object can be used as an argument for summary.lme.morph() and plot.lme.morph() to provide standard errors, confidence intervals, and p-values based on bootstrapping rather than asymptotic approximations.

Usage

boot.morph(object, B = 1000, control = NULL, progressbar = TRUE, n.cores = 1)

Arguments

object

An object of class lme.morph, returned by fit.morph().

B

An integer, providing the number of bootstrap resamples.

control

A list of control values for the estimation algorithm to replace the default values returned by the function nlme::lmeControl().

progressbar

Logical. If TRUE a progress bar will be displayed.

n.cores

Integer. The number of cores for parallel processing.

Value

The original object, with additional bootstrapping information that can be used by summary.lme.morph() and plot.lme.morph()

Examples


## Fitting model to manta ray data.
fit <- fit.morph(manta)
## Carrying out a parametric bootstrap.
fit.boot <- boot.morph(fit, B = 100)
## Standard errors based on a bootstrap will be a little different
## to those based on asymptotic approximations.
summary(fit)
summary(fit.boot)



morphErr documentation built on Aug. 30, 2026, 5:06 p.m.