| calc.conditional.ratio | R Documentation |
Calculates a ratio between dimensions, conditional on the denominator. Used internally by plotting functions.
calc.conditional.ratio(
fit,
stders = TRUE,
y.dim,
x.dim,
newdata.x.dim,
type = "lm"
)
fit |
A fitted model object of class "lme.morph" |
y.dim |
Integer specifying numerator dimension |
x.dim |
Integer specifying denominator dimension |
newdata.x.dim |
Numeric vector of values for denominator dimension |
type |
Character string, either "lm" or "pca", specifying calculation method |
Calculates ratios between dimensions conditional on the denominator dimension value. Can use either linear model or PCA interpretation for the calculations.
A matrix with columns:
Estimate |
Conditional ratio estimates |
Std. Error |
Standard errors for the estimates |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.