| construct.varcov | R Documentation |
Takes standard deviations and correlation parameters, and organises them into a block-diagonal variance-covariance matrix.
construct.varcov(sds, cors, n.blocks, m, block.only)
sds |
Numeric vector of standard deviations for each dimension |
cors |
Numeric vector of correlation parameters between dimensions |
n.blocks |
Integer, number of blocks in the matrix |
m |
Integer, number of dimensions measured |
block.only |
Logical, if TRUE returns only one block rather than the full matrix |
A variance-covariance matrix
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.