manta: Manta Ray Morphometric Data

mantaR Documentation

Manta Ray Morphometric Data

Description

Data collected on a drone photogrammetry survey of the reef manta ray Mobula alfredi in Raja Ampat, Indonesia.

Usage

manta

Format

manta

A data frame with four columns:

animal.id

An individual identification number. Rows with the same animal.id correspond to measurements of the same individual manta ray.

photo.id

A photo identification number. Rows with the same photo.id correspond to measurements taken from the same image.

dim

An integer indicating the dimension the measurement is for. Here, 1 is for disc width, 2 is for disc length, and 3 is for cranial width.

measurement

The observed measurement value in centimetres.


morphErr documentation built on Aug. 30, 2026, 5:06 p.m.