| manta | R Documentation |
Data collected on a drone photogrammetry survey of the reef manta ray Mobula alfredi in Raja Ampat, Indonesia.
manta
mantaA data frame with four columns:
animal.idAn individual identification number. Rows
with the same animal.id correspond to
measurements of the same individual manta ray.
photo.idA photo identification number. Rows with
the same photo.id correspond to
measurements taken from the same image.
dimAn integer indicating the dimension the
measurement is for. Here, 1 is for disc width,
2 is for disc length, and 3 is for
cranial width.
measurementThe observed measurement value in centimetres.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.