| plot.lme.morph | R Documentation |
An S3 method that plots morphometric data, estimated relationships
between dimensions, or both, from a fitted model object returned by
fit.morph().
## S3 method for class 'lme.morph'
plot(
x,
dims = c(1, 2),
type = "data",
line.type = "lm",
confints = !add,
add = FALSE,
reverse.axes = FALSE,
plot.data = TRUE,
xlim = NULL,
ylim = NULL,
xlab = NULL,
ylab = NULL,
...
)
x |
An object of class |
dims |
An integer vector of length two, indicating which dimensions will appear on the x- and y-axes, respectively. |
type |
A character string specifying the plot type. If
|
line.type |
A character string specifying the type of fitted
line to overlay. If |
confints |
Logical. If |
add |
Logical. If |
reverse.axes |
Logical. If |
plot.data |
Logical. If |
xlim, ylim |
Limits for the axes. |
xlab, ylab |
Titles for the axes. |
... |
Additional arguments passed to |
No return value. Called to produce a plot.
## Fitting model to manta ray data.
fit <- fit.morph(manta)
## Plotting dimensions 1 and 2 with a fitted linear regression
## line.
plot(fit)
## Same again, but plotting the reduced major axis (or principal
## component axis) for dimensions 1 and 3.
plot(fit, dims = c(1, 3), line.type = "pca")
## A plot showing how the ratio between dimensions 2 and 3 changes
## with the size of dimension 3. Because the line is quite flat,
## it's plausible the relationship is isometric.
plot(fit, dims = c(3, 2), type = "ratio", line.type = "pca")
## On the other hand, the relationship between dimensions 1 and 2
## is clearly allometric.
plot(fit, dims = c(3, 1), type = "ratio", line.type = "pca")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.