| plotmorph | R Documentation |
Creates scatter plots of morphometric measurements, with options for different dimension combinations and plotting of ratios.
plotmorph(
data,
dims = c(1, 2),
plot.data = TRUE,
ratios = FALSE,
xlim = NULL,
ylim = NULL,
xlab = NULL,
ylab = NULL
)
data |
A data frame containing the morphometric data. See the section below on the correct formatting of this argument. |
dims |
An integer vector of length two, indicating which dimensions will appear on the x- and y-axes, respectively. |
plot.data |
Logical. If |
ratios |
Logical. If |
xlim, ylim |
Limits for the axes. |
xlab, ylab |
Titles for the axes. |
No return value. Called to produce a plot.
data argumentThe manta object is an example of a correctly formatted
data argument. It must be a data frame with the following
columns:
animal.idAn individual identification number. Rows
with the same animal.id correspond to
measurements of the saime individual manta ray.
photo.idA photo identification number. Rows with
the same photo.id correspond to
measurements taken from the same image.
photo.idAn integer indicating the dimension the measurement is for.
measurementThe corresponding measurement.
## Plotting dimensions 1 and 2.
plotmorph(manta)
## Plotting dimensions 1 and 3.
plotmorph(manta, dims = c(1, 3))
## Plotting the ratio of dimension 2 divided by dimension 1 on the
## y-axis.
plotmorph(manta, dims = c(1, 2), ratios = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.