| summary.lme.morph | R Documentation |
An S3 method that creates summaries of fitted morphometric models. This function can provide different types of summaries including parameter estimates, beta coefficients, and tests for isometry.
## S3 method for class 'lme.morph'
summary(object, ..., type = "pars", y.dim, x.dim, level = 0.95)
object |
An object of class |
... |
Other parameters (for S3 generic compatibility). |
type |
A character string specifying type of summary. Either
|
y.dim |
An integer specifying the response dimension for when
|
x.dim |
An integer vector specifying the explanatory
dimensions for when |
level |
The confidence level for any interval estimates. |
The following summaries are available with this method,
controlled by the type argument:
type = "pars"Estimates and standard errors for the model parameters, including
the vectors \mu for the means of the true dimension sizes,
\sigma for the standard deviations for true dimension sizes,
\rho for the correlations between true dimension sizes,
\psi for the standard deviations in measurement errors for
the dimensions, and \phi for the correlations between
measurement errors for all pairs of dimensions.
type = "betas" or type = "betas-lm"Estimates and standard errors for coefficients of a linear
combination that provides the expected value of one dimension
(specified by y.dim) using any subset of the remaining dimensions
(specified in the vector x.dim).
type = "betas-pca"An estimated intercept and slope for the reduced major axis (or
principal component axis) summarising the relationship between the
true values of dimensions specified by y.dim and x.dim.
type = "isometric-pca"Results for tests of the null hypotheses of isometric relationships between all pairs of dimensions. The p-values are obtained using normal approximations for the test statistics.
For models with log.transform = FALSE, the test statistic to test
for isometric growth between dimensions p and q is
\mu_p\sigma_q - \mu_q\sigma_p, which is equal to 0
under the null hypothesis.
For models with log.transform = TRUE, the test statistic is the
slope for the reduced major axis (or principal component axis)
summarising the relationship between the two dimensions, which is
equal to 1 under the null hypothesis.
A matrix or data frame containing the requested summary.
## Fitting model to manta ray data.
fit <- fit.morph(manta)
## Parameter estimates and standard errors.
summary(fit)
## Estimated coefficients for the linear combination that provides
## the expected value of the first dimension from only the second.
summary(fit, type = "betas-lm", y.dim = 1, x.dim = 2)
## Estimated coefficients for the linear combination that provides
## the expected value of the second dimension from both the first
## and third.
summary(fit, type = "betas-lm", y.dim = 2, x.dim = c(1, 3))
## Estimated intercept and slope for the reduced major axis (or
## pricipal component axis) summarising the relationship between
## the first and second dimensions.
summary(fit, type = "betas-pca", y.dim = 1, x.dim = 2)
## Tests for isometry between all pairs of dimensions.
summary(fit, type = "isometric-pca")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.